from django.conf.urls.defaults import *

# @@@ from atom import Feed

from notification.views import notices, mark_all_seen, feed_for_user, single

urlpatterns = patterns('',
    url(r'^$', notices, name="notification_notices"),
    url(r'^(\d+)/$', single, name="notification_notice"),
    url(r'^feed/$', feed_for_user, name="notification_feed_for_user"),
    url(r'^mark_all_seen/$', mark_all_seen, name="notification_mark_all_seen"),
)



from notification.models import Notice

def notification(request):
    if request.user.is_authenticated():
        return {'notice_unseen_count': Notice.objects.unseen_count_for(request.user),}
    else:
        return {}



from distutils.core import setup

setup(
    name='django-notification',
    version=__import__('notification').__version__,
    description='Many sites need to notify users when certain events have occurred and to allow configurable options as to how those notifications are to be received. The project aims to provide a Django app for this sort of functionality.',
    long_description=open('docs/index.txt').read(),
    author='James Tauber',
    author_email='jtauber@jtauber.com',
    url='http://code.google.com/p/django-notification/',
    packages=[
        'notification',
        'notification.management',
        'notification.management.commands',
    ],
    package_dir={'notification': 'notification'},
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
    ]
)
